@@ -2,20 +2,20 @@
  *
  * Copyright (C) 2003 - 2006 Vivien Malerba
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
+ * This Library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This Library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
+ * You should have received a copy of the GNU Library General Public
+ * License along with this Library; see the file COPYING.LIB.  If not,
+ * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #include <string.h>
@@ -142,7 +142,7 @@ gda_dict_database_get_type (void)
 {
 	static GType type = 0;
 
-	if (!type) {
+	if (G_UNLIKELY (type == 0)) {
 		static const GTypeInfo info = {
 			sizeof (GdaDictDatabaseClass),
 			(GBaseInitFunc) NULL,
@@ -189,72 +189,75 @@ gda_dict_database_class_init (GdaDictDatabaseClass * class)
                               G_SIGNAL_RUN_FIRST,
                               G_STRUCT_OFFSET (GdaDictDatabaseClass, table_added),
                               NULL, NULL,
-                              gda_marshal_VOID__POINTER,
-                              G_TYPE_NONE, 1, G_TYPE_POINTER);
+                              gda_marshal_VOID__OBJECT,
+                              G_TYPE_NONE, 1, GDA_TYPE_DICT_TABLE);
 	gda_dict_database_signals[TABLE_REMOVED] =
                 g_signal_new ("table_removed",
                               G_TYPE_FROM_CLASS (object_class),
                               G_SIGNAL_RUN_FIRST,
                               G_STRUCT_OFFSET (GdaDictDatabaseClass, table_removed),
                               NULL, NULL,
-                              gda_marshal_VOID__POINTER,
-                              G_TYPE_NONE, 1, G_TYPE_POINTER);
+                              gda_marshal_VOID__OBJECT,
+                              G_TYPE_NONE, 1, GDA_TYPE_DICT_TABLE);
 	gda_dict_database_signals[TABLE_UPDATED] =
                 g_signal_new ("table_updated",
                               G_TYPE_FROM_CLASS (object_class),
                               G_SIGNAL_RUN_FIRST,
                               G_STRUCT_OFFSET (GdaDictDatabaseClass, table_updated),
                               NULL, NULL,
-                              gda_marshal_VOID__POINTER,
-                              G_TYPE_NONE, 1, G_TYPE_POINTER);
+                              gda_marshal_VOID__OBJECT,
+                              G_TYPE_NONE, 1, GDA_TYPE_DICT_TABLE);
+
         gda_dict_database_signals[FIELD_ADDED] =
                 g_signal_new ("field_added",
                               G_TYPE_FROM_CLASS (object_class),
                               G_SIGNAL_RUN_FIRST,
                               G_STRUCT_OFFSET (GdaDictDatabaseClass, field_added),
                               NULL, NULL,
-                              gda_marshal_VOID__POINTER,
-                              G_TYPE_NONE, 1, G_TYPE_POINTER);
+                              gda_marshal_VOID__OBJECT,
+                              G_TYPE_NONE, 1, GDA_TYPE_DICT_FIELD);
         gda_dict_database_signals[FIELD_REMOVED] =
                 g_signal_new ("field_removed",
                               G_TYPE_FROM_CLASS (object_class),
                               G_SIGNAL_RUN_FIRST,
                               G_STRUCT_OFFSET (GdaDictDatabaseClass, field_removed),
                               NULL, NULL,
-                              gda_marshal_VOID__POINTER,
-                              G_TYPE_NONE, 1, G_TYPE_POINTER);
+                              gda_marshal_VOID__OBJECT,
+                              G_TYPE_NONE, 1, GDA_TYPE_DICT_FIELD);
         gda_dict_database_signals[FIELD_UPDATED] =
                 g_signal_new ("field_updated",
                               G_TYPE_FROM_CLASS (object_class),
                               G_SIGNAL_RUN_FIRST,
                               G_STRUCT_OFFSET (GdaDictDatabaseClass, field_updated),
                               NULL, NULL,
-                              gda_marshal_VOID__POINTER,
-                              G_TYPE_NONE, 1, G_TYPE_POINTER);
+                              gda_marshal_VOID__OBJECT,
+                              G_TYPE_NONE, 1, GDA_TYPE_DICT_FIELD);
+
         gda_dict_database_signals[CONSTRAINT_ADDED] =
                 g_signal_new ("constraint_added",
                               G_TYPE_FROM_CLASS (object_class),
                               G_SIGNAL_RUN_FIRST,
                               G_STRUCT_OFFSET (GdaDictDatabaseClass, constraint_added),
                               NULL, NULL,
-                              gda_marshal_VOID__POINTER,
-                              G_TYPE_NONE, 1, G_TYPE_POINTER);
+                              gda_marshal_VOID__OBJECT,
+                              G_TYPE_NONE, 1, GDA_TYPE_DICT_CONSTRAINT);
         gda_dict_database_signals[CONSTRAINT_REMOVED] =
                 g_signal_new ("constraint_removed",
                               G_TYPE_FROM_CLASS (object_class),
                               G_SIGNAL_RUN_FIRST,
                               G_STRUCT_OFFSET (GdaDictDatabaseClass, constraint_removed),
                               NULL, NULL,
-                              gda_marshal_VOID__POINTER,
-                              G_TYPE_NONE, 1, G_TYPE_POINTER);
+                              gda_marshal_VOID__OBJECT,
+                              G_TYPE_NONE, 1, GDA_TYPE_DICT_CONSTRAINT);
         gda_dict_database_signals[CONSTRAINT_UPDATED] =
                 g_signal_new ("constraint_updated",
                               G_TYPE_FROM_CLASS (object_class),
                               G_SIGNAL_RUN_FIRST,
                               G_STRUCT_OFFSET (GdaDictDatabaseClass, constraint_updated),
                               NULL, NULL,
-                              gda_marshal_VOID__POINTER,
-                              G_TYPE_NONE, 1, G_TYPE_POINTER);
+                              gda_marshal_VOID__OBJECT,
+                              G_TYPE_NONE, 1, GDA_TYPE_DICT_CONSTRAINT);
+
 	gda_dict_database_signals[DATA_UPDATE_STARTED] =
                 g_signal_new ("data_update_started",
                               G_TYPE_FROM_CLASS (object_class),
@@ -269,8 +272,8 @@ gda_dict_database_class_init (GdaDictDatabaseClass * class)
                               G_SIGNAL_RUN_FIRST,
                               G_STRUCT_OFFSET (GdaDictDatabaseClass, update_progress),
                               NULL, NULL,
-                              gda_marshal_VOID__POINTER_UINT_UINT,
-                              G_TYPE_NONE, 3, G_TYPE_POINTER, G_TYPE_UINT, G_TYPE_UINT);
+                              gda_marshal_VOID__STRING_UINT_UINT,
+                              G_TYPE_NONE, 3, G_TYPE_STRING, G_TYPE_UINT, G_TYPE_UINT);
 	gda_dict_database_signals[DATA_UPDATE_FINISHED] =
                 g_signal_new ("data_update_finished",
                               G_TYPE_FROM_CLASS (object_class),
@@ -296,7 +299,7 @@ gda_dict_database_class_init (GdaDictDatabaseClass * class)
 	object_class->dispose = gda_dict_database_dispose;
 	object_class->finalize = gda_dict_database_finalize;
 
-        #if 0 /* This object does not have any properties.
+#if 0 /* This object does not have any properties.*/
 	/* Properties */
 	object_class->set_property = gda_dict_database_set_property;
 	object_class->get_property = gda_dict_database_get_property;
@@ -1067,11 +1070,11 @@ database_tables_update_list (GdaDictDatabase *db, const gchar *table_name, GErro
 
 	/* tables */
 	rs = gda_connection_get_schema (cnc, GDA_CONNECTION_SCHEMA_TABLES, options, NULL);
-	if (options)
-		g_object_unref (options);
 	if (!rs) {
 		g_set_error (error, GDA_DICT_DATABASE_ERROR, GDA_DICT_DATABASE_TABLES_ERROR,
 			     _("Can't get list of tables"));
+		if (options) 
+			g_object_unref (options);
 		return FALSE;
 	}
 	updated_tables = database_tables_n_views_update_treat_schema_result (db, rs, FALSE, error);
@@ -1080,8 +1083,11 @@ database_tables_update_list (GdaDictDatabase *db, const gchar *table_name, GErro
 
 	/* views */
 	rs = gda_connection_get_schema (cnc, GDA_CONNECTION_SCHEMA_VIEWS, options, NULL);
-	if (options)
+	if (options) {
 		g_object_unref (options);
+		options = NULL;
+	}
+
 	if (!rs) {
 		g_set_error (error, GDA_DICT_DATABASE_ERROR, GDA_DICT_DATABASE_TABLES_ERROR,
 			     _("Can't get list of views"));
