@@ -2,20 +2,20 @@
  *
  * Copyright (C) 2003 - 2005 Vivien Malerba
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
+ * This Library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This Library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
+ * You should have received a copy of the GNU Library General Public
+ * License along with this Library; see the file COPYING.LIB.  If not,
+ * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 
@@ -86,7 +86,7 @@ struct _GdaQueryConditionClass
 	GdaQueryObjectClass        parent_class;
 };
 
-GType                 gda_query_condition_get_type                (void);
+GType                 gda_query_condition_get_type                (void) G_GNUC_CONST;
 GdaQueryCondition    *gda_query_condition_new                     (GdaQuery *query, GdaQueryConditionType type);
 GdaQueryCondition    *gda_query_condition_new_copy                (GdaQueryCondition *orig, GHashTable *replacements);
 GdaQueryCondition    *gda_query_condition_new_from_sql            (GdaQuery *query, const gchar *sql_cond, 
