@@ -1,8 +1,9 @@
 /* GDA Xbase Provider
- * Copyright (C) 1998-2002 The GNOME Foundation
+ * Copyright (C) 1998 - 2007 The GNOME Foundation
  *
  * AUTHORS:
  *         Rodrigo Moya <rodrigo@gnome-db.org>
+ *         Vivien Malerba <malerba@gnome-db.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -19,7 +20,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <libgda/gda-intl.h>
+#include <glib/gi18n-lib.h>
 #include "gda-xbase-database.h"
 #include "gda-xbase-provider.h"
 
@@ -47,25 +48,10 @@ static const gchar *gda_xbase_provider_get_database (GdaServerProvider *provider
 static gboolean gda_xbase_provider_change_database (GdaServerProvider *provider,
 						    GdaConnection *cnc,
 						    const gchar *name);
-static gboolean gda_xbase_provider_create_database (GdaServerProvider *provider,
-						    GdaConnection *cnc,
-						    const gchar *name);
-static gboolean gda_xbase_provider_drop_database (GdaServerProvider *provider,
-						  GdaConnection *cnc,
-						  const gchar *name);
 static GList *gda_xbase_provider_execute_command (GdaServerProvider *provider,
 						  GdaConnection *cnc,
 						  GdaCommand *cmd,
 						  GdaParameterList *params);
-static gboolean gda_xbase_provider_begin_transaction (GdaServerProvider *provider,
-						      GdaConnection *cnc,
-						      GdaTransaction *xaction);
-static gboolean gda_xbase_provider_commit_transaction (GdaServerProvider *provider,
-						       GdaConnection *cnc,
-						       GdaTransaction *xaction);
-static gboolean gda_xbase_provider_rollback_transaction (GdaServerProvider *provider,
-							 GdaConnection *cnc,
-							 GdaTransaction *xaction);
 static gboolean gda_xbase_provider_supports (GdaServerProvider *provider,
 					     GdaConnection *cnc,
 					     GdaConnectionFeature feature);
@@ -94,20 +80,38 @@ gda_xbase_provider_class_init (GdaXbaseProviderClass *klass)
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 
 	object_class->finalize = gda_xbase_provider_finalize;
+
 	provider_class->get_version = gda_xbase_provider_get_version;
+	provider_class->get_server_version = gda_xbase_provider_get_server_version;
+	provider_class->get_info = NULL;
+	provider_class->supports_feature = gda_xbase_provider_supports;
+	provider_class->get_schema = gda_xbase_provider_get_schema;
+
+	provider_class->get_data_handler = NULL;
+	provider_class->string_to_value = NULL;
+	provider_class->get_def_dbms_type = NULL;
+
+	provider_class->create_connection = NULL;
 	provider_class->open_connection = gda_xbase_provider_open_connection;
 	provider_class->close_connection = gda_xbase_provider_close_connection;
-	provider_class->get_server_version = gda_xbase_provider_get_server_version;
 	provider_class->get_database = gda_xbase_provider_get_database;
 	provider_class->change_database = gda_xbase_provider_change_database;
-	provider_class->create_database = gda_xbase_provider_create_database;
-	provider_class->drop_database = gda_xbase_provider_drop_database;
+
+	provider_class->supports_operation = NULL;
+        provider_class->create_operation = NULL;
+        provider_class->render_operation = NULL;
+        provider_class->perform_operation = NULL;
+
 	provider_class->execute_command = gda_xbase_provider_execute_command;
-	provider_class->begin_transaction = gda_xbase_provider_begin_transaction;
-	provider_class->commit_transaction = gda_xbase_provider_commit_transaction;
-	provider_class->rollback_transaction = gda_xbase_provider_rollback_transaction;
-	provider_class->supports = gda_xbase_provider_supports;
-	provider_class->get_schema = gda_xbase_provider_get_schema;
+	provider_class->execute_query = NULL;
+	provider_class->get_last_insert_id = NULL;
+
+	provider_class->begin_transaction = NULL;
+	provider_class->commit_transaction = NULL;
+	provider_class->rollback_transaction = NULL;
+	provider_class->add_savepoint = NULL;
+	provider_class->rollback_savepoint = NULL;
+	provider_class->delete_savepoint = NULL;
 }
 
 static void
@@ -131,7 +135,7 @@ gda_xbase_provider_get_type (void)
 {
 	static GType type = 0;
 
-	if (!type) {
+	if (G_UNLIKELY (type == 0)) {
 		static GTypeInfo info = {
 			sizeof (GdaXbaseProviderClass),
 			(GBaseInitFunc) NULL,
@@ -181,7 +185,7 @@ gda_xbase_provider_open_connection (GdaServerProvider *provider,
 	p_directory = gda_quark_list_find (params, "DIRECTORY");
 
 	if ((p_filename && p_directory)) {
-		gda_connection_add_error_string (
+		gda_connection_add_event_string (
 			cnc, _("Either FILENAME or DIRECTORY can be specified, but not both or neither"));
 		return FALSE;
 	}
@@ -197,7 +201,7 @@ gda_xbase_provider_open_connection (GdaServerProvider *provider,
 		pdata->using_directory = FALSE;
 		xdb = gda_xbase_database_open (cnc, p_filename);
 		if (xdb) {
-			g_hash_table_insert (pdata->databases, gda_xbase_database_get_name (xdb), xdb);
+			g_hash_table_insert (pdata->databases, p_filename, xdb);
 		} else {
 			gda_xbase_provider_close_connection (provider, cnc);
 			return FALSE;
@@ -209,7 +213,7 @@ gda_xbase_provider_open_connection (GdaServerProvider *provider,
 		pdata->using_directory = TRUE;
 		dir = g_dir_open (p_directory, 0, &error);
 		if (error) {
-			gda_connection_add_error_string (cnc, error->message);
+			gda_connection_add_event_string (cnc, error->message);
 			g_error_free (error);
 			return FALSE;
 		}
@@ -218,9 +222,9 @@ gda_xbase_provider_open_connection (GdaServerProvider *provider,
 			gchar *s = g_build_path (p_directory, p_filename);
 			xdb = gda_xbase_database_open (cnc, p_filename);
 			if (xdb) {
-				g_hash_table_insert (pdata->databases, gda_xbase_database_get_name (xdb), xdb);
+				g_hash_table_insert (pdata->databases, p_filename, xdb);
 			} else {
-				gda_connection_add_error_string (cnc, _("Could not open file %s"), s);
+				gda_connection_add_event_string (cnc, _("Could not open file %s"), s);
 			}
 
 			g_free (s);
@@ -228,7 +232,7 @@ gda_xbase_provider_open_connection (GdaServerProvider *provider,
 
 		g_dir_close (dir);
 	} else {
-		gda_connection_add_error_string (
+		gda_connection_add_event_string (
 			cnc, _("Either FILENAME or DIRECTORY must be specified in the connection string"));
 		gda_xbase_provider_close_connection (provider, cnc);
 		return FALSE;
@@ -258,7 +262,7 @@ gda_xbase_provider_close_connection (GdaServerProvider *provider, GdaConnection
 
 	pdata = (GdaXbaseProviderData *) g_object_get_data (G_OBJECT (cnc), CONNECTION_DATA);
 	if (!pdata) {
-		gda_connection_add_error_string (cnc, _("Invalid Xbase handle"));
+		gda_connection_add_event_string (cnc, _("Invalid Xbase handle"));
 		return FALSE;
 	}
 
@@ -295,23 +299,6 @@ gda_xbase_provider_change_database (GdaServerProvider *provider,
 	return FALSE;
 }
 
-/* create_database handler for the GdaXbaseProvider class */
-static gboolean
-gda_xbase_provider_create_database (GdaServerProvider *provider,
-				    GdaConnection *cnc,
-				    const gchar *name)
-{
-}
-
-/* drop_database handler for the GdaXbaseProvider class */
-static gboolean
-gda_xbase_provider_drop_database (GdaServerProvider *provider,
-				      GdaConnection *cnc,
-				      const gchar *name)
-{
-	return FALSE;
-}
-
 /* execute_command handler for the GdaXbaseProvider class */
 static GList *
 gda_xbase_provider_execute_command (GdaServerProvider *provider,
@@ -321,30 +308,6 @@ gda_xbase_provider_execute_command (GdaServerProvider *provider,
 {
 }
 
-/* begin_transaction handler for the GdaXbaseProvider class */
-static gboolean
-gda_xbase_provider_begin_transaction (GdaServerProvider *provider,
-					  GdaConnection *cnc,
-					  GdaTransaction *xaction)
-{
-}
-
-/* commit_transaction handler for the GdaXbaseProvider class */
-static gboolean
-gda_xbase_provider_commit_transaction (GdaServerProvider *provider,
-					   GdaConnection *cnc,
-					   GdaTransaction *xaction)
-{
-}
-
-/* rollback_transaction handler for the GdaXbaseProvider class */
-static gboolean
-gda_xbase_provider_rollback_transaction (GdaServerProvider *provider,
-					     GdaConnection *cnc,
-					     GdaTransaction *xaction)
-{
-}
-
 /* supports handler for the GdaXbaseProvider class */
 static gboolean
 gda_xbase_provider_supports (GdaServerProvider *provider,
@@ -369,20 +332,20 @@ gda_xbase_provider_get_schema (GdaServerProvider *provider,
 void
 gda_xbase_provider_make_error (GdaConnection *cnc)
 {
-	GdaError *error;
+	GdaConnectionEvent *error;
 	GdaXbaseProviderData *pdata;
 
 	g_return_if_fail (GDA_IS_CONNECTION (cnc));
 
 	pdata = (GdaXbaseProviderData *) g_object_get_data (G_OBJECT (cnc), CONNECTION_DATA);
 	if (!pdata) {
-		gda_connection_add_error_string (cnc, _("Invalid Xbase handle"));
+		gda_connection_add_event_string (cnc, _("Invalid Xbase handle"));
 		return;
 	}
 
-	error = gda_error_new ();
+	error = gda_connection_event_new (GDA_CONNECTION_EVENT_ERROR);
 	/* FIXME: get error information */
-	gda_error_set_source (error, "[GDA Xbase]");
+	gda_connection_event_set_source (error, "[GDA Xbase]");
 
-	gda_connection_add_error (cnc, error);
+	gda_connection_add_event (cnc, error);
 }
